/*
 * geanypy-keybindings.h
 *
 * Copyright 2015 Thomas Martitz <kugel@rockbox.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */


#ifndef GEANYPY_KEYBINDINGS_H
#define GEANYPY_KEYBINDINGS_H

#include <glib.h>

typedef struct
{
	PyObject_HEAD
	GeanyKeyGroup *kb_group;
	gboolean has_cb;
	gint item_index;
} KeyGroup;

extern PyObject *
KeyGroup_new_with_geany_key_group(GeanyKeyGroup *group, gboolean has_cb);

#endif /* GEANYPY_KEYBINDINGS_H */
